@@ -3,7 +3,7 @@ package WWW::Mechanize::Image;
 use strict;
 use warnings;
 
-our $VERSION = '1.92';
+our $VERSION = '1.93';
 
 #ABSTRACT: Image object for WWW::Mechanize
 
@@ -69,7 +69,7 @@ WWW::Mechanize::Image - Image object for WWW::Mechanize
 
 =head1 VERSION
 
-version 1.92
+version 1.93
 
 =head1 SYNOPSIS
 
@@ -94,43 +94,45 @@ Creates and returns a new C<WWW::Mechanize::Image> object.
 
 =head1 Accessors
 
-=head2 $link->url()
+=head2 $image->url()
 
-URL from the link
+Image URL from the C<src> attribute of the source tag.
 
-=head2 $link->base()
+May be C<undef> if source tag has no C<src> attribute.
+
+=head2 $image->base()
 
 Base URL to which the links are relative.
 
-=head2 $link->name()
+=head2 $image->name()
 
 Name for the field from the NAME attribute, if any.
 
-=head2 $link->tag()
+=head2 $image->tag()
 
 Tag name (either "image" or "input")
 
-=head2 $link->height()
+=head2 $image->height()
 
 Image height
 
-=head2 $link->width()
+=head2 $image->width()
 
 Image width
 
-=head2 $link->alt()
+=head2 $image->alt()
 
 ALT attribute from the source tag, if any.
 
-=head2 $link->attrs()
+=head2 $image->attrs()
 
 Hash ref of all the attributes and attribute values in the tag.
 
-=head2 $link->URI()
+=head2 $image->URI()
 
 Returns the URL as a L<URI::URL> object.
 
-=head2 $link->url_abs()
+=head2 $image->url_abs()
 
 Returns the URL as an absolute URL string.
 
